# Upgrade steps from 7.0 to 7.1

See `doc/bc/changes-7.1.md` for requirements changes and deprecations.

## Kernel removal

Class `eZ\Bundle\EzPublishCoreBundle\Kernel` has been removed. It has not been needed since 5.4 and has not been in use
starting with eZ Platform 1.12.

Change the following in `app/AppKernel.php` to adapt:
```diff
-use eZ\Bundle\EzPublishCoreBundle\Kernel;
+use Symfony\Component\HttpKernel\Kernel;
```

### HttpCache removal

Class `eZ\Bundle\EzPublishCoreBundle\HttpCache` has been removed. It has been deprecated since 1.12, and has been replaced
by corresponding class in `ezplatform-http-cache` package.

Change the following in `app/AppCache.php` to adapt:
```diff
-use eZ\Bundle\EzPublishCoreBundle\HttpCache;
+use EzSystems\PlatformHttpCacheBundle\AppCache as HttpCache;
```

### User identify / hash generation removal

Builtin user hash generation feature as made possible porviding services tagged with `ezpublish.identity_definer` has been
removed.

It has been possible to use plain FosHttpCache(Bundle) feature for this since 5.4.


Example:
```yml
    MyApp\ContextProvider\IsAuthenticatedProvider:
        arguments: ["@my.user_service"]
        tags:
            - { name: fos_http_cache.user_context_provider }
```

```php
namespace MyApp\ContextProvider;

use FOS\HttpCache\UserContext\ContextProviderInterface;
// In FosHttpCache 2.x this has been renamed, so pay attention to this when ezplatform-http-cache updates.
// use FOS\HttpCache\UserContext\ContextProvider as ContextProviderInterface;
use FOS\HttpCache\UserContext\UserContext;

class IsAuthenticatedProvider implements ContextProviderInterface
{
    protected $userService;

    public function __construct(YourUserService $userService)
    {
        $this->userService = $userService;
    }

    public function updateUserContext(UserContext $userContext)
    {
        $userContext->addParameter('authenticated', $this->userService->isAuthenticated());
    }
}
```
